%define _legacy_common_support 1

Name:           tvheadend
Summary:        TV streaming server
Version:        4.3
Release:        %mkrel 4
License:        GPLv3
URL:            https://tvheadend.org/
Group:          Video/Television
Source0:        %{name}-%{version}.tar.gz
Source1:        %{name}.init
Source2:        %{name}.png
Source4:        %{name}.conf
Source5:        README.install.urpmi
Patch0:         016de1aae4d2951794005dc5b72345bcb3f700b0.patch
Patch1:         tvheadend-4.3-more-gcc7-fixes.patch
Patch2:         tvheadend-4.2.5-gcc8.patch
Patch3:         tvheadend-4.3-git-strlcpy.patch
Patch8:         tvheadend-4.2.8-gcc10.patch
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(avahi-client)
BuildRequires:  libgcrypt-devel

Requires(post): pwgen
Requires(pre):  rpm-helper
Requires(preun):rpm-helper

%description
Tvheadend is a TV streaming server for Linux supporting DVB-S, DVB-S2, DVB-C,
DVB-T, ATSC, IPTV, and Analog video (V4L) as input sources.

For the full list of features see the documentation at:
https://www.lonelycoder.com/hts/tvheadend/docs/2_12/index.html

%prep
%setup -q
%autopatch -p1

%build
%set_build_flags
%configure \
    --release \
    --disable-dvbscan \
    --disable-libav \
    --disable-hdhomerun_static \
    --disable-ffmpeg_static \
    --disable-libx264_static \
    --disable-libx265_static \
    --disable-libvpx_static \
    --disable-libtheora_static \
    --disable-libvorbis_static
%make_build

%install
%make_install

cp -v %{SOURCE5} .

mkdir -p %{buildroot}%{_localstatedir}/lib/%{name}/.hts/%{name}/accesscontrol
cp -v %{SOURCE4} %{buildroot}%{_localstatedir}/lib/%{name}/.hts/%{name}/accesscontrol/1

mkdir -p %{buildroot}%{_iconsdir}
cp -v %{SOURCE2} %{buildroot}%{_iconsdir}/%{name}.png

mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{name}.desktop << EOF
[Desktop Entry]
Name=Tvheadend
Comment=TV streaming server
Exec=%{_bindir}/xdg-open http://localhost:9981/
Icon=%{_iconsdir}/%{name}
Type=Application
Categories=AudioVideo;Video;TV;Recorder;X-Mageia-CrossDesktop;
EOF

mkdir -p %{buildroot}%{_initddir}
install -m 0755 %{SOURCE1} %{buildroot}/%{_initddir}/%{name}

chmod +x %{buildroot}%{_bindir}/%name

%pre
# create a user "tvheadend" with a home directory /var/lib/tvheadend
# with no login shell and make him a member of the video group
%_pre_useradd %{name} %{_localstatedir}/lib/%{name} /sbin/nologin
gpasswd -a %{name} video >/dev/null

%post
chown %{name}:root %{_localstatedir}/lib/%{name} 
cd %{_localstatedir}/lib/%{name}
chown -R %{name}:video .hts*

# check if the access control file still has the initial dummy password, and
# replace the dummy password by a random, 12-character pwgen-generated password
if  grep -q '"password": "dummypassword"' %{_localstatedir}/lib/%{name}/.hts/%{name}/accesscontrol/1; then
  sed -i "s,\"password\": \"dummypassword\",\"password\": \"$(pwgen -s 12 1)\"," %{_localstatedir}/lib/%{name}/.hts/%{name}/accesscontrol/1
fi

%_post_service %{name}

%preun
%_preun_service %{name}

%files
%doc LICENSE.md README.md
%doc README.install.urpmi
%{_bindir}/%name
%{_initddir}/%name
%{_mandir}/man1/%name.1*
%{_iconsdir}/%name.png
%{_datadir}/applications/%{name}.desktop
%{_datadir}/%{name}

#home directory and config file 
%dir %attr(-,tvheadend,root) %{_localstatedir}/lib/%{name}
%dir %attr(-,tvheadend,video) %{_localstatedir}/lib/%{name}/.hts/%{name}/accesscontrol
%attr(0600,tvheadend,video) %{_localstatedir}/lib/%{name}/.hts/%{name}/accesscontrol/1



%changelog
* Fri Nov 13 2020 tv <tv> 4.3-4.mga8
+ Revision: 1644985
- fix build on 32bit
- fix build

* Thu Apr 16 2020 umeabot <umeabot> 4.3-3.mga8
+ Revision: 1567730
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x
- replace deprecated %%setup_compile_flags

* Tue Oct 02 2018 daviddavid <daviddavid> 4.3-2.mga7
+ Revision: 1315866
- add patch to fix build with gcc8
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild

* Thu Sep 07 2017 guillomovitch <guillomovitch> 4.3-1.mga7
+ Revision: 1151801
- new version 4.3

* Mon Feb 13 2017 eatdirt <eatdirt> 4.0.9-1.mga6
+ Revision: 1086031
- Upgrade to version 4.0.9

* Sun Jan 22 2017 daviddavid <daviddavid> 3.2.18-7.mga6
+ Revision: 1083061
- remove useless BRs on kdelibs4-devel and qt4-devel
- fix Comment key on desktop file

* Mon Feb 08 2016 umeabot <umeabot> 3.2.18-6.mga6
+ Revision: 942884
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 3.2.18-5.mga5
+ Revision: 741963
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.2.18-4.mga5
+ Revision: 689994
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 3.2.18-3.mga4
+ Revision: 519814
- Mageia 4 Mass Rebuild

* Mon Jan 14 2013 umeabot <umeabot> 3.2.18-2.mga3
+ Revision: 384907
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Jan 09 2013 anssi <anssi> 3.2.18-1.mga3
+ Revision: 343709
- update group
- new version
- drop now unneeded patches (mandir.patch, cflags.patch)

* Thu Jan 05 2012 doktor5000 <doktor5000> 2.12-1.mga2
+ Revision: 191744
- temporary workaround for compilation with gcc-4.6
- use %%{_bindir} instead of /usr/bin in .desktop file
- remove unused start script from spec
- use %%setup_compile_flags
- drop %%ifarch-applying of patch
- drop %%ifarch-configure
- fix cflags.patch, so that the Makefile does not overwrite our CFLAGS
- add LSB headers to init script, added Default-Stop for runlevels 0 and 6,
  remove commented-out line
- replaced start script with direct call from .desktop file and avoid
  calling tvheadend a second time additionally to the init script
- fix Icon entry in .desktop file, add X-Mageia-CrossDesktop to categories to
  no display it in "More" sub-menu
- use gpasswd instead of usermod -G, since "usermod -G" replaces groups
  instead of adding them
- check for the existence of the dummy password before replacing it with the
  pwgen-generated one, grep/sed the whole string as safety measure
- move manpage to correct location (mandir.patch)
- use %%{_prefix} instead of /usr
- change README.urpmi to README.install.urpmi, change encoding to UTF8,
  proofread & reword README.install.urpmi, remove german parts
- minor cosmetics
- imported package tvheadend

